aboutsummaryrefslogtreecommitdiff
path: root/gold/script.h
diff options
context:
space:
mode:
authorIan Lance Taylor <iant@google.com>2008-02-28 19:46:06 +0000
committerIan Lance Taylor <iant@google.com>2008-02-28 19:46:06 +0000
commitda769d5629564b82d4eec1b256ffc562d5c01624 (patch)
treec575a166927823074cd07dad6347b0e90072340f /gold/script.h
parenta7dfd0102bbf259cad78b322915523adb366837a (diff)
downloadgdb-da769d5629564b82d4eec1b256ffc562d5c01624.zip
gdb-da769d5629564b82d4eec1b256ffc562d5c01624.tar.gz
gdb-da769d5629564b82d4eec1b256ffc562d5c01624.tar.bz2
Read input scripts which look like input objects with proper
serialization.
Diffstat (limited to 'gold/script.h')
-rw-r--r--gold/script.h13
1 files changed, 6 insertions, 7 deletions
diff --git a/gold/script.h b/gold/script.h
index 78d9ff0..ea19cfa 100644
--- a/gold/script.h
+++ b/gold/script.h
@@ -381,17 +381,16 @@ class Script_options
};
// FILE was found as an argument on the command line, but was not
// recognized as an ELF file. Try to read it as a script. We've
// already read BYTES of data into P. Return true if the file was
// handled. This has to handle /usr/lib/libc.so on a GNU/Linux
// system.
bool
read_input_script(Workqueue*, const General_options&, Symbol_table*, Layout*,
Dirsearch*, Input_objects*, Input_group*,
- const Input_argument*, Input_file*, const unsigned char* p,
- off_t bytes, Task_token* this_blocker,
- Task_token* next_blocker);
+ const Input_argument*, Input_file*,
+ Task_token* next_blocker, bool* used_next_blocker);
// FILE was found as an argument to --script (-T).
// Read it as a script, and execute its contents immediately.
@@ -381,17 +381,16 @@ class Script_options
};
// FILE was found as an argument on the command line, but was not
-// recognized as an ELF file. Try to read it as a script. We've
-// already read BYTES of data into P. Return true if the file was
-// handled. This has to handle /usr/lib/libc.so on a GNU/Linux
-// system.
+// recognized as an ELF file. Try to read it as a script. Return
+// true if the file was handled. This has to handle /usr/lib/libc.so
+// on a GNU/Linux system. *USED_NEXT_BLOCKER is set to indicate
+// whether the function took over NEXT_BLOCKER.
bool
read_input_script(Workqueue*, const General_options&, Symbol_table*, Layout*,